@@ -103,7 +103,7 @@
 #define ADIOS2_HAVE_SYSVSHMEM
 
 /* CMake Option: ADIOS2_USE_UCX=OFF */
-/* #undef ADIOS2_HAVE_UCX */
+#define ADIOS2_HAVE_UCX
 
 /* CMake Option: ADIOS2_USE_ZeroMQ=OFF */
 #define ADIOS2_HAVE_ZEROMQ
@@ -142,7 +142,7 @@
 #define ADIOS2_HAVE_CAMPAIGN
 
 
-#define ADIOS2_FEATURE_LIST "DATAMAN","HDF5","MHS","SST","FORTRAN","MPI","PYTHON","BZIP2","PNG","SZ","ZFP","O_DIRECT","SODIUM","SYSVSHMEM","ZEROMQ","PROFILING","CAMPAIGN",nullptr
+#define ADIOS2_FEATURE_LIST "DATAMAN","HDF5","MHS","SST","FORTRAN","MPI","PYTHON","BZIP2","PNG","SZ","ZFP","O_DIRECT","SODIUM","SYSVSHMEM","UCX","ZEROMQ","PROFILING","CAMPAIGN",nullptr
 
 /* Everything between here and the note above is programatically generated */
 
